# Sample package

```{eval-rst}
.. automodule:: sec_certs.sample
    :no-members:
```

```{tip}
The examples related to this package can be found at [common criteria notebook](./../notebooks/examples/common_criteria.ipynb) and [fips notebook](./../notebooks/examples/fips.ipynb).
```

## CommonCriteriaCert

```{eval-rst}
.. currentmodule:: sec_certs.sample
.. autoclass:: CommonCriteriaCert
    :members:
```

## FIPSCertificate

```{eval-rst}
.. currentmodule:: sec_certs.sample
.. autoclass:: FIPSCertificate
    :members:
```